summaryrefslogtreecommitdiff
path: root/drivers/gpu/drm/xe/xe_lrc_types.h
diff options
context:
space:
mode:
Diffstat (limited to 'drivers/gpu/drm/xe/xe_lrc_types.h')
-rw-r--r--drivers/gpu/drm/xe/xe_lrc_types.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/gpu/drm/xe/xe_lrc_types.h b/drivers/gpu/drm/xe/xe_lrc_types.h
index 8fe08535873d..78220336062c 100644
--- a/drivers/gpu/drm/xe/xe_lrc_types.h
+++ b/drivers/gpu/drm/xe/xe_lrc_types.h
@@ -20,8 +20,8 @@ struct xe_lrc {
*/
struct xe_bo *bo;
- /** @full_gt: full GT which this LRC belongs to */
- struct xe_gt *full_gt;
+ /** @tile: tile which this LRC belongs to */
+ struct xe_tile *tile;
/** @flags: LRC flags */
u32 flags;